@@ -10,21 +10,12 @@ BEGIN { plan tests => 1 };
 use Finance::Currency::Convert::Yahoo;
 ok(1); # If we made it this far, we're ok.
 
-print <<"__STOP__";
-
-If you are online, and want a test, please run the following:
-
-	use Finance::Currency::Convert::Yahoo;
-	print Finance::Currency::Convert::Yahoo::convert(1,'USD','GBP');
-
-Ta.
-
-__STOP__
+#$CHAT=1;
+#print convert(10,'GBP','HUF');
+# exit;
 
 #########################
 
 # Insert your test code below, the Test module is use()ed here so read
 # its man page ( perldoc Test ) for help writing this test script.
 
-
-print Finance::Currency::Convert::Yahoo::convert(1,'USD','GBP');
